@@ -4,19 +4,17 @@
 #' flux_param_lm is for fit in the lm family (linear and quadratic)
 #' flux_param_exp is for the exponential fit
 #' @param slopes_df the slopes_df that is being provided to flux_plot
-#' @param f_conc column with gas concentration
 #' @importFrom dplyr select group_by mutate ungroup distinct filter
+#' @keywords internal
 
-flux_param_kappamax <- function(slopes_df,
-                                f_conc) {
+flux_param_kappamax <- function(slopes_df) {
   param_df <- slopes_df |>
     select(
-      {{f_conc}}, "f_start", "f_fluxid", "f_RMSE", "f_cor_coef", "f_b",
+      "f_start", "f_facetid", "f_RMSE", "f_cor_coef", "f_b",
       "f_gfactor", "f_cut", "f_quality_flag", "f_model",
       "f_rsquared_lm", "f_pvalue_lm"
     ) |>
     filter(.data$f_cut != "cut") |>
-    select(!{{f_conc}}) |>
     distinct() |>
     mutate(
       f_rsquared_lm = round(.data$f_rsquared_lm, digits = 2),
@@ -46,7 +44,7 @@ flux_param_kappamax <- function(slopes_df,
         str_detect(.data$f_model, "exp") ~ print_col_exp
       )
     ) |>
-    select("f_start", "f_fluxid", "print_col", "f_quality_flag")
+    select("f_start", "f_facetid", "print_col", "f_quality_flag")
 
   param_df
 }
