@@ -34,7 +34,10 @@ flux_plot_quadratic <- function(slopes_df,
   plot_quadratic <- slopes_df |>
     ggplot(aes({{f_datetime}})) +
     theme_bw() +
-    geom_vline(xintercept = slopes_df$f_start_z,
+    geom_vline(aes(xintercept = .data$f_start_z),
+               data = distinct(
+                 slopes_df, .data$f_facetid, .keep_all = TRUE
+               ),
                color = "grey", linewidth = 0.5) +
     geom_point(aes(y = {{f_conc}}, color = .data$f_quality_flag),
       size = 0.4,
